"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
class ActiveExecutions {
    constructor() {
        this.nextId = 1;
        this.activeExecutions = {};
        this.stopExecutions = [];
    }
    add(workflow, runExecutionData, mode) {
        const executionId = this.nextId++;
        this.activeExecutions[executionId] = {
            runExecutionData,
            startedAt: new Date().getTime(),
            mode,
            workflow,
            postExecutePromises: [],
        };
        return executionId.toString();
    }
    remove(executionId, fullRunData) {
        if (this.activeExecutions[executionId] === undefined) {
            return;
        }
        for (const promise of this.activeExecutions[executionId].postExecutePromises) {
            promise.resolve(fullRunData);
        }
        delete this.activeExecutions[executionId];
        const stopExecutionIndex = this.stopExecutions.indexOf(executionId);
        if (stopExecutionIndex !== -1) {
            this.stopExecutions.splice(stopExecutionIndex, 1);
        }
    }
    async stopExecution(executionId) {
        if (this.activeExecutions[executionId] === undefined) {
            return;
        }
        if (!this.stopExecutions.includes(executionId)) {
            this.stopExecutions.push(executionId);
        }
        return this.getPostExecutePromise(executionId);
    }
    async getPostExecutePromise(executionId) {
        const waitPromise = await _1.createDeferredPromise();
        if (this.activeExecutions[executionId] === undefined) {
            throw new Error(`There is no active execution with id "${executionId}".`);
        }
        this.activeExecutions[executionId].postExecutePromises.push(waitPromise);
        return waitPromise.promise();
    }
    shouldBeStopped(executionId) {
        return this.stopExecutions.includes(executionId);
    }
    getActiveExecutions() {
        const returnData = [];
        let executionData;
        for (const id of Object.keys(this.activeExecutions)) {
            executionData = this.activeExecutions[id];
            returnData.push({
                id,
                startedAt: executionData.startedAt,
                mode: executionData.mode,
                workflowId: executionData.workflow.id,
            });
        }
        return returnData;
    }
}
exports.ActiveExecutions = ActiveExecutions;
let activeExecutionsInstance;
function getInstance() {
    if (activeExecutionsInstance === undefined) {
        activeExecutionsInstance = new ActiveExecutions();
    }
    return activeExecutionsInstance;
}
exports.getInstance = getInstance;
//# sourceMappingURL=ActiveExecutions.js.map